Module common

Module common 

Shared utilities for graph algorithms

Provides a read-only, optimized view of the graph topology for algorithm execution.

Structs

GraphView
A dense, integer-indexed view of the graph topology using Compressed Sparse Row (CSR) format.

Type Aliases

NodeId
Node Identifier type (u64)